/*******************************************************************************
* Title: 74HC595_Setup.c                                                       *
* Version: 1.0                                                                 *
* Author: Jeff Nybo                                                            *
* Date: November 13, 2010                                                      *
*                                                                              *
* Description:                                                                 *
* This file contains the functions that setup the 74HC595 8-Bit Shift Register *
* and send data to it via the Serial Peripheral Interface. (SPI)               *
*******************************************************************************/

/*******************************************************************************
* Function: Init_595(void)                                                     * 
*                                                                              *
* Variables:                                                                   *
* N/A                                                                          *
*                                                                              *
* Description:                                                                 *
* This function will reset the 74HC595's, making sure that they are ready to   *
* receive data.                                                                *
*******************************************************************************/
void Init_595(void)
{
  Reset_595();  //Reset the 74HC595's
  LAT_595 = 0;  //Put latch in its default off state
} 

/*******************************************************************************
* Function: Reset_595(void)                                                    * 
*                                                                              *
* Variables:                                                                   *
* N/A                                                                          *
*                                                                              *
* Description:                                                                 *
* This function allows the user to reset the 74HC595's back to their default   *
* off state.                                                                   *
*******************************************************************************/
void Reset_595(void)
{
  RST_595 = 0; //Pulse RST_595 low for a short amount of time, resetting the device
  Nop();
  RST_595 = 1; //Return RST_595 back to its default inactive state
}  

/*******************************************************************************
* Function: SPI_Send_595(uint32 data)                                          * 
*                                                                              *
* Variables:                                                                   *
* data -> Contains the 4 bytes of data that are to be sent to the 74HC595's    *
*                                                                              *
* Description:                                                                 *
* This function will transfer the 4 bytes of data which will allow the user    *
* to control each blue LED individually. This function also controls the       *
* LED Lemon and Bottle with the use of bit#7 and bit#6 in the variable 'data'. *
*******************************************************************************/                   
void SPI_Send_595(uint32 data)
{
  LEMON = (data >> 7) & 0x00000001;   //Turn the lemon on if bit#7 is high and  turn it off if bit#7 is low
  BOTTLE = (data >> 6) & 0x00000001; //Turn the bottle on if bit#6 is high and turn it off it bit#6 is low

  SPI_Send(data >> 24);           //Shift out byte #1 first (IC1)
  SPI_Send((data >> 16) & 0x000000FF);  //Shift out byte #2 next (IC2)
  SPI_Send((data >> 8) & 0x000000FF);   //Shift out byte #3 next (IC3)
  SPI_Send(data & 0x0000000F);  //Shift out byte #4 last (IC4)

  LAT_595 = 1;   //Latch the data onto the outputs of the 74HC595's
  Nop();
  LAT_595 = 0;  //Reset the latch to its default state
}
