/*******************************************************************************
* Title: Corona_Bottle                                                         *
* Version: 1.0                                                                 *
* Author: Jeff Nybo                                                            *
* Date: June 13, 2011                                                          *
*                                                                              *
* Description:                                                                 *
* This project contains all the source code that has the ability to read the   * 
* inputs of an LM3915 VU Meter and control an array of LEDs individually.      * 
*******************************************************************************/

/*************************************************
* Include device file and configuration settings *
*************************************************/
#include <p18f4550.h>
#include <stdio.h>
#include <stdlib.h>
#include "StandardConfig.h"
#include "PORT_Setup.h"
#include "Delay_Setup.h"
#include "SPI_Setup.h"
#include "Interrupt_Control.h"
#include "74HC595_Setup.h"
#include "Miscellaneous.h"

/*******************************************************************************
* Function: InterruptVectorHigh()                                              * 
*                                                                              *
* Variables:                                                                   *
* N/A                                                                          *
*                                                                              *
* Description:                                                                 *
* This function handles all of the High Priority interrupt routines. All high  *
* priority interrupts begin at code location 0x0008.                           *
*******************************************************************************/
#pragma code HIGH_INTERRUPT_VECTOR = 0x0008
void InterruptVectorHigh(void)
{
  _asm goto ISR_High _endasm
}

/*******************************************************************************
* Function: InterruptVectorLow()                                               * 
*                                                                              *
* Variables:                                                                   *
* N/A                                                                          *
*                                                                              *
* Description:                                                                 *
* This function handles all of the Low Priority interrupt routines. All low    *
* priority interrupts begin at code location 0x0018.                           *
*******************************************************************************/
#pragma code LOW_INTERRUPT_VECTOR = 0x0018
void InterruptVectorLow(void)
{
  _asm goto ISR_Low _endasm
}

/*******************************************************************************
* Function: main()                                                             * 
*                                                                              *
* Variables:                                                                   *
* N/A                                                                          *
*                                                                              *
* Description:                                                                 *
* All of the code in the program is ran from inside this function. This        *
* function will never terminate as long as the MCU has power applied to it.    *
*******************************************************************************/
void main(void)
{ 
  PORT_Init(); //Initialize all the PORTs
  Init_595();  //Ready the 74HC595 for data
  SPI_Init(SPI_ON | TX_A_I | IDLE_H | MAS_4);  //Initialize SPI module and enable it

  while(1)
  {  
    VU_Meter(); //Display the VU Meter
  }
}
/*************************************************
*                Included C Files                *
*************************************************/
#include "PORT_Setup.c"
#include "Delay_Setup.c"
#include "SPI_Setup.c"
#include "Interrupt_Control.c"
#include "74HC595_Setup.c"
#include "Miscellaneous.c"
