/*******************************************************************************
* Title: Interrupt_Control.c                                                   *
* Version: 1.0                                                                 *
* Author: Jeff Nybo                                                            *
* Date: January 24, 2011                                                       *
*                                                                              *
* Description:                                                                 *
* This file contains the functions that enable all interrupts and control the  *
* operation of the high and low interrupts.                                    *
*******************************************************************************/

/*******************************************************************************
* Function: ISR_High(void)                                                     * 
*                                                                              *
* Variables:                                                                   *
* N/A                                                                          *
*                                                                              *
* Description:                                                                 *
* This function handles all of the High Priority interrupt routines. All high  *
* priority interrupts begin at code location 0x0008.                           *
*******************************************************************************/
#pragma interrupt ISR_High
void ISR_High(void)
{  	

}  

/*******************************************************************************
* Function: ISR_Low(void)                                                      * 
*                                                                              *
* Variables:                                                                   *
* N/A                                                                          *
*                                                                              *
* Description:                                                                 *
* This function handles all of the Low Priority interrupt routines. All low    *
* priority interrupts begin at code location 0x0018.                           *
*******************************************************************************/
#pragma interruptlow ISR_Low
void ISR_Low(void)
{	

}

/*******************************************************************************
* Function: Enable_Interrupts(void)                                            * 
*                                                                              *
* Variables:                                                                   *
* N/A                                                                          *
*                                                                              *
* Description:                                                                 *
* This function will enable all high and low interrupts.                       *
*******************************************************************************/
void Interrupts_Init(byte state)
{
  RCONbits.IPEN = 1;		//Enable priority levels on interrupts
  INTCONbits.PEIE = 1;	//Enable all unmasked peripheral interrupts
  INTCONbits.GIE = 0x01 & state;		//Enable/Disable all global interrupts
}
