/*******************************************************************************
* Title: Miscellaneous.c                                                       *
* Version: 1.0                                                                 *
* Author: Jeff Nybo                                                            *
* Date: June 13, 2011                                                          *
*                                                                              *
* Description:                                                                 *
* This file contains miscellaneous functions that are used in the project.     *
*******************************************************************************/

/*******************************************************************************
* Function: VU_Meter(void)                                                     * 
*                                                                              *
* Variables:                                                                   *
* N/A                                                                          *
*                                                                              *
* Description:                                                                 *
* This function will control all of the 28 blue LEDs according to the level of *
* sound that is read from the LM3915.                                          *
*******************************************************************************/
void VU_Meter(void)
{
  uint16 level;
  
  level = (0xF0 & (uint16)PORTD) << 2; //Mask off RD3 - RD0 and put RD4 - RD7 from bit#6 - bit#9
  level |= ((0xFC & PORTB) >> 2);  //Mask off RB0 and RB1 and save RB2 - RB7 in the lower 6 bits of level
  
  switch (level)
  {
   case LEVEL_01: SPI_Send_595(0xE00000C0); break; //Sound level 1
   case LEVEL_02: SPI_Send_595(0xFC0000C0); break; //Sound level 2
   case LEVEL_03: SPI_Send_595(0xFF8000C0); break; //Sound level 3
   case LEVEL_04: SPI_Send_595(0xFFF000C0); break; //Sound level 4
   case LEVEL_05: SPI_Send_595(0xFFFE00C0); break; //Sound level 5
   case LEVEL_06: SPI_Send_595(0xFFFFC0C0); break; //Sound level 6
   case LEVEL_07: SPI_Send_595(0xFFFFF8C0); break; //Sound level 7
   case LEVEL_08: SPI_Send_595(0xFFFFFFC0); break; //Sound level 8
   case LEVEL_09: SPI_Send_595(0xFFFFFFCC); break; //Sound level 9
   case LEVEL_10: SPI_Send_595(0xFFFFFFCF); break; //Sound level 10
   case LEVEL_00: SPI_Send_595(0x000000C0); break; //Sound level 0
   default:       SPI_Send_595(0x000000C0); break;
  }    
}    
  
/*******************************************************************************
* Function: Animation(void)                                                    * 
*                                                                              *
* Variables:                                                                   *
* N/A                                                                          *
*                                                                              *
* Description:                                                                 *
* This function performs a simple LED animation where the outer blue LEDs fill *
* upwards to the top then flow down the middle to the bottom.                  *
*******************************************************************************/
void Animation(void)
{
  uint16 time = 80;
  
  SPI_Send_595(0xA0000000);
  Delay_ms(time); 
  
  SPI_Send_595(0xB4000000);
  Delay_ms(time); 
  
  SPI_Send_595(0xB6800000);
  Delay_ms(time); 
  
  SPI_Send_595(0xB6D00000);
  Delay_ms(time); 
  
  SPI_Send_595(0xB6DA0000);
  Delay_ms(time); 
  
  SPI_Send_595(0xB6DB4000);
  Delay_ms(time); 
  
  SPI_Send_595(0xB6DB6800);
  Delay_ms(time); 
  
  SPI_Send_595(0xB6DB6D00);
  Delay_ms(time); 
  
  SPI_Send_595(0xB6DB6D0C);
  Delay_ms(time); 
  
  SPI_Send_595(0xB6DB6D0F);
  Delay_ms(time); 
  
  SPI_Send_595(0xB6DB6F0F);
  Delay_ms(time); 
  
  SPI_Send_595(0xB6DB7F0F);
  Delay_ms(time); 
  
  SPI_Send_595(0xB6DBFF0F);
  Delay_ms(time); 
  
  SPI_Send_595(0xB6DFFF0F);
  Delay_ms(time); 
  
  SPI_Send_595(0xB6FFFF0F);
  Delay_ms(time); 
  
  SPI_Send_595(0xB7FFFF0F);
  Delay_ms(time); 
  
  SPI_Send_595(0xBFFFFF0F);
  Delay_ms(time); 
  
  SPI_Send_595(0xFFFFFF0F);
  Delay_ms(time); 
   
}  
