/*******************************************************************************
* Title: PORT_Setup.c                                                          *
* Version: 1.0                                                                 *
* Author: Jeff Nybo                                                            *
* Date: June 13, 2011                                                          *
*                                                                              *
* Description:                                                                 *
* This file contains the functions that are used for setting up and            *
* initializing the ports and register.                                         *
*******************************************************************************/

/*******************************************************************************
* Function: PORT_Init(void)                                                    * 
*                                                                              *
* Variables:                                                                   *
* N/A                                                                          *
*                                                                              *
* Pinouts:                                                                     *
*                                                                              *
* RA0 -> N/C                                                                   *
* RA1 -> N/C                                                                   *
* RA2 -> N/C                                                                   *
* RA3 -> N/C                                                                   *
* RA4 -> N/C                                                                   *
* RA5 -> N/C                                                                   *
*                                                                              *
* RB0 -> N/C                                                                   *
* RB1 -> SCK on 74HC595                                                        *
* RB2 -> LED6 output on LM3915                                                 *
* RB3 -> LED5 output on LM3915                                                 *
* RB4 -> LED4 output on LM3915                                                 *
* RB5 -> LED3 output on LM3915                                                 *
* RB6 -> LED2 output on LM3915                                                 *
* RB7 -> LED1 output on LM3915                                                 *
*                                                                              *
* RC0 -> N/C                                                                   *
* RC1 -> Yellow LED Control (Lemon)                                            *
* RC2 -> Green LED Control (Bottle)                                            *
* RC4 -> N/C                                                                   *
* RC5 -> N/C                                                                   *
* RC6 -> N/C                                                                   *
* RC7 -> SER on 74HC595                                                        *
*                                                                              *
* RD0 -> N/C                                                                   *
* RD1 -> N/C                                                                   *
* RD2 -> SCL on 74HC595 (Reset)                                                *
* RD3 -> RCK on 74HC595 (Latch)                                                *
* RD4 -> LED10 output on LM3915                                                *
* RD5 -> LED9 output on LM3915                                                 *
* RD6 -> LED8 output on LM3915                                                 *
* RD7 -> LED7 output on LM3915                                                 *
*                                                                              *
* RE0 -> S2 Tactile Switch (Active Low)                                        *
* RE1 -> N/C                                                                   *
* RE2 -> N/C                                                                   *
*                                                                              *
* **All N/C pins are set as low outputs                                        *
*                                                                              *
* Description:                                                                 *
* This routine will initialize the ports as needed according to the schematic. *
* This should only be called once in a program.                                *
*******************************************************************************/
void PORT_Init(void)
{
 CMCON  = 0x07;  //Disable Comparator Module
 ADCON1 = 0x1F;
 ADCON0 = 0x00;
 ADCON2 = 0xAB;

 PORTB = 0x00; //All connections are labeled above
 PORTA = 0xFF;
 PORTD = 0x08;
 PORTC = 0xFF;
 PORTE = 0xFF;

 TRISA = 0X00;  
 TRISB = 0XFD;
 TRISC = 0X00;
 TRISD = 0XF0;
 TRISE = 0X00;
}
