/*******************************************************************************
* Title: SPI_Setup.c                                                           *
* Version: 1.0                                                                 *
* Author: Jeff Nybo                                                            *
* Date: November 13, 2010                                                      *
*                                                                              *
* Description:                                                                 *
* This file contains the functions that allow the user to set up the SPI and   *
* send and receive data.                                                       *
*******************************************************************************/
            
/*******************************************************************************
* Function: SPI_Init(void)                                                     *
*                                                                              *
* Variables:                                                                   *
* N/A                                                                          *
*                                                                              *
* Description:                                                                 *
* This function will initialize SPI and enable or disable it according to the  * 
* value of state. (Disable -> state = 0x00 : Enable -> state = 0x20)           *
*******************************************************************************/
void SPI_Init(uint16 setup)
{
  PIE1bits.SSPIE = 0;
  PIR1bits.SSPIF = 0;
  SSPSTAT = setup >> 8;       //SSPSTAT is equal to the high byte of setup
  SSPCON1 = 0x00FF & setup;   //SSPCON1 is equal to the low byte of setup 
  
  if (0x0020 & setup)
  {
   TRISCbits.TRISC7 = 0; 
   TRISBbits.TRISB0 = 1;
   TRISBbits.TRISB1 = 0;
  
   SSPCON1bits.SSPEN = 1;
  }  
}

/*******************************************************************************
* Function: SPI_Send(byte Tx)                                                  *
*                                                                              *
* Variables:                                                                   *
* Tx -> The value of the data that is to be transmitted                        *
*                                                                              *
* Description:                                                                 *
* This function will send the value of Tx while receiving and storing the data * 
* on SDI in Rx. The function will then return the value of Rx.                 *
*******************************************************************************/
byte SPI_Send(byte Tx) 
{
  PIR1bits.SSPIF = 0; 
  
  SSPBUF = Tx;
  while (!SSPSTATbits.BF); 
  
//  while (!PIR1bits.SSPIF);  
  
  return SSPBUF;
}

/*******************************************************************************
* Function:                                                                    * 
*                                                                              *
* Variables:                                                                   *
* N/A                                                                          *
*                                                                              *
* Description:                                                                 *
*                                                                              *
*                                                                              *
*******************************************************************************/
void SPI_State(byte state)
{
 if (state == 0)
 {
  SSPCON1bits.SSPEN = 0; 
 }  
 
 else
 {
  TRISCbits.TRISC7 = 0; 
  TRISBbits.TRISB0 = 1;
  TRISBbits.TRISB1 = 0;
  
  SSPCON1bits.SSPEN = 1;
 }     
} 
